package il.co.iter.dbdom;

import java.sql.SQLException;

 /**
  * <code>DOMSpException</code> is thrown if a stored procedure does not
  * return a result set that is specified in DBDOM.
  *
  * <p>This exception indicates that the connection is to a database that is
  * incompatible with DBDOM or that there is a version missmatch between the
  * database and the Java wrappers.
  */

public class DBDOMSpException extends DBDOMException {

    private static String msgPrefix = "stored procedure";
    private static String msgSuffix = "did not return the expected result set";

     /**
      * Constructs a {@link DBDOMSpException} with a default message.
      */
    public DBDOMSpException () {
        super(msgPrefix + " " + msgSuffix);
    }

     /**
      * Constructs a {@link DBDOMSpException} with the name of the offending
      * SP in the message.
      *
      * @param spName name of the stored procedure that returned the
      * unexpected result.
      */
    public DBDOMSpException (String spName) {
        super(msgPrefix + " " + spName + " " + msgSuffix);
    }
}
