package il.co.iter.dbdom;

import org.w3c.dom.DocumentType;
import org.w3c.dom.NamedNodeMap;
import org.w3c.dom.DOMException;

/**
 * Each <code>Document</code> has a <code>doctype</code> attribute whose value
 * is either <code>null</code> or a <code>DocumentType</code> object. The
 * <code>DocumentType</code> interface in the DOM Core provides an interface
 * to the list of entities that are defined for the document, and little
 * else because the effect of namespaces and the various XML schema efforts
 * on DTD representation are not clearly understood as of this writing.
 * <p>The DOM Level 2 doesn't support editing <code>DocumentType</code> nodes.
 * <p>See also the <a href='http://www.w3.org/TR/2000/REC-DOM-Level-2-Core-20001113'>Document Object Model (DOM) Level 2 Core Specification</a>.
 */
public class DBDocumentType extends DBNode implements DocumentType {

    /** <strong>Not Implemented</strong>
     * Calls super(dbDomImplementation, id)
     */
    protected DBDocumentType (DBDOMImplementation dbDomImplementation, long id) {
        super(dbDomImplementation, id);
    }
    /** <strong>Not Implemented</strong>
     * The name of DTD; i.e., the name immediately following the
     * <code>DOCTYPE</code> keyword.
     */
    public String getName() {
        throw new DOMException(DOMException.NOT_SUPPORTED_ERR, "this feature is not implemented");
    }

    /** <strong>Not Implemented</strong>
     * A <code>NamedNodeMap</code> containing the general entities, both
     * external and internal, declared in the DTD. Parameter entities are
     * not contained. Duplicates are discarded. For example in:
     * <pre>&lt;!DOCTYPE
     * ex SYSTEM "ex.dtd" [ &lt;!ENTITY foo "foo"&gt; &lt;!ENTITY bar
     * "bar"&gt; &lt;!ENTITY bar "bar2"&gt; &lt;!ENTITY % baz "baz"&gt;
     * ]&gt; &lt;ex/&gt;</pre>
     *  the interface provides access to <code>foo</code>
     * and the first declaration of <code>bar</code> but not the second
     * declaration of <code>bar</code> or <code>baz</code>. Every node in
     * this map also implements the <code>Entity</code> interface.
     * <br>The DOM Level 2 does not support editing entities, therefore
     * <code>entities</code> cannot be altered in any way.
     */
    public NamedNodeMap getEntities() {
        throw new DOMException(DOMException.NOT_SUPPORTED_ERR, "this feature is not implemented");
    }

    /** <strong>Not Implemented</strong>
     * A <code>NamedNodeMap</code> containing the notations declared in the
     * DTD. Duplicates are discarded. Every node in this map also implements
     * the <code>Notation</code> interface.
     * <br>The DOM Level 2 does not support editing notations, therefore
     * <code>notations</code> cannot be altered in any way.
     */
    public NamedNodeMap getNotations() {
        throw new DOMException(DOMException.NOT_SUPPORTED_ERR, "this feature is not implemented");
    }

    /** <strong>Not Implemented</strong>
     * The public identifier of the external subset.
     * @since DOM Level 2
     */
    public String getPublicId() {
        throw new DOMException(DOMException.NOT_SUPPORTED_ERR, "this feature is not implemented");
    }

    /** <strong>Not Implemented</strong>
     * The system identifier of the external subset.
     * @since DOM Level 2
     */
    public String getSystemId() {
        throw new DOMException(DOMException.NOT_SUPPORTED_ERR, "this feature is not implemented");
    }

    /** <strong>Not Implemented</strong>
     * The internal subset as a string.The actual content returned depends on 
     * how much information is available to the implementation. This may 
     * vary depending on various parameters, including the XML processor 
     * used to build the document.
     * @since DOM Level 2
     */
    public String getInternalSubset() {
        throw new DOMException(DOMException.NOT_SUPPORTED_ERR, "this feature is not implemented");
    }

}
