package il.co.iter.dbdom.samples;

import java.sql.*;
import org.w3c.dom.*;
import il.co.iter.dbdom.*;
import il.co.iter.dbdom.parsers.*;

// these are needed for the GUI
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.tree.*;
import javax.swing.event.*;
import javax.swing.filechooser.*;
import ui.*;

// these are needed for import / export
import java.io.*;
import org.xml.sax.*;

// this is needed for export
import org.apache.xml.serialize.*;

/**
 * This class displays a read-only gui for a DBDOM database;
 * It uses classes from the ui package included with Apache xerces distribution.
 */

public class Gui extends JFrame {

    private static final String TITLE_PREFIX = "DBDOM alpha demo";

    private DBDOMImplementation dbDomImplementation;
    // all documents stored in a database
    private NamedNodeMap documents;

    final JFileChooser fileChooser = new JFileChooser();
    private DOMTreeFull  domTree = new DOMTreeFull();
    // alternative display
    //DOMTree  domTree = new DOMTree();

    public Gui (final DBDOMImplementation dbDomImplementation) {
        super(TITLE_PREFIX);
        this.dbDomImplementation = dbDomImplementation;

        documents = dbDomImplementation.getDocuments();

        super.setSize(500, 300);

        JScrollPane scrollPane = new JScrollPane (domTree);

        super.getContentPane().add(scrollPane);

        JMenuBar jmb = new JMenuBar();
        JMenu fileMenu = new JMenu("File");
        JMenuItem item;

        item = new JMenuItem("Import Document");
        fileMenu.add(item);
        item.addActionListener(new GuiFileImporter());

        item = new JMenuItem("Export Document");
        fileMenu.add(item);
        item.addActionListener(new GuiFileExporter());


        item = new JMenuItem("Exit");
        fileMenu.add(item);
        item.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                System.exit(1);  	
            }
        });

        final JMenu documentsMenu = new JMenu("Documents");
        documentsMenu.addMenuListener(new MenuListener () {
                public void menuSelected(MenuEvent e) {
                    for (int i = 0; i < documents.getLength(); i++) {
                        String documentName = ((DBDocument)documents.item(i)).getDocumentName();
                        JMenuItem item = new JMenuItem(documentName);
                        documentsMenu.add(item);
                        item.addActionListener(new ActionListener() {
                            public void actionPerformed(ActionEvent e) {
                                domTree.setRootNode (documents.getNamedItem(e.getActionCommand()));
                                // for alternative display
                                //domTree.setDocument ((Document)documents.getNamedItem(e.getActionCommand()));
                                Gui.this.setTitle (TITLE_PREFIX + ": " + e.getActionCommand());
                            }
                        });
                    }
                }
                public void menuDeselected(MenuEvent e) {
                }
                public void menuCanceled(MenuEvent e) {
                }
            });


        jmb.add(fileMenu);
        jmb.add(documentsMenu);
        setJMenuBar(jmb);

    }

    /**
     * Runs the Gui demo. Expects a jdbc driver name, a connection string, a
     * username and an optional password to open a connection to the database.
     * <p>If no password is supplied on the command line, tries to connect
     * with a blank password.
     *
     * <p>The interface isn't great, but keep in mind that this calss
     * deomnstrates the DBDOM implementation rather than command line options
     * or fancy GUI.
     *
     * <p>A shell script, <code>runGui</code>, is available that can be edited
     * to avoid typing long command line options.
     *
     * <p>Usage:<br>
     * <code>java il.co.iter.dbdom.samples.Gui <jdbc driver classname>
     * <connection string> <username> [password]</code>
     */
    public static void main (String[] argv) {
        if (argv.length != 3 && argv.length != 4) {
            printUsage();
            System.exit(0);
        }
        try {
            Class.forName(argv[0]);
        } catch (ClassNotFoundException cnf) {
            cnf.printStackTrace();
            System.exit(1);
        }
		
        Connection con = null;
		
        try {
            if (argv.length == 3) {
                con = DriverManager.getConnection (argv[1], argv[2], "");
            } else {
                con = DriverManager.getConnection (argv[1], argv[2], argv[3]);
            }
        } catch (SQLException sqle) {
            sqle.printStackTrace();
            System.exit(1);
        }

        DBDOMImplementation dbdom = null;;

        try {
            dbdom = new DBDOMImplementation (con);
        } catch (Exception e) {
            e.printStackTrace();
            System.exit(1);
        }

        Gui gui = new Gui (dbdom);
        gui.addWindowListener(new java.awt.event.WindowAdapter() {
            public void windowClosing(java.awt.event.WindowEvent e) {
                System.exit(0);
            }
        });
        gui.setVisible (true);
    }

    private class GuiFileImporter implements ActionListener {
        public void actionPerformed(ActionEvent e) {
            if (fileChooser.showOpenDialog(Gui.this) == JFileChooser.APPROVE_OPTION) {
                try {
                    String documentFileName = fileChooser.getSelectedFile().getCanonicalPath();
                    Object documentName = documentFileName;
                    while (documentName != null &&
                           dbDomImplementation.getDocuments().getNamedItem(documentName.toString()) != null) {
                        documentName = JOptionPane.showInputDialog(
                                Gui.this,
                                "A document named\n" +
                                    documentName +
                                    "\nalready exists in the databse.\nImport document as:",
                                "Select alternative name",
                                JOptionPane.QUESTION_MESSAGE,
                                null,                          // no icon
                                null,                          // no restrictions on input
                                documentName);
                    }
                    if (documentName != null) /* which means action wasn't canceled */ {
                        // this is where the actual import happens
                        // create a new document in the database and parse the file into it
                        try {
                            dbDomImplementation.setAutoCommit (false);
                            DBDocument dbDocument = dbDomImplementation.createNamedDocument(documentName.toString());
                            DBDOMParser parser = new DBDOMParser(dbDocument);
                            parser.setFeature ("http://xml.org/sax/features/namespaces", false);
                            parser.parse (documentFileName);
                            dbDomImplementation.commit();
                            domTree.setRootNode (dbDocument);
                            Gui.this.setTitle (TITLE_PREFIX + ": " + documentName);
                        } catch (SAXException se) {
                            dbDomImplementation.rollback();
                            JOptionPane.showMessageDialog(Gui.this, se, "SAX Excpetion", JOptionPane.ERROR_MESSAGE);
                        } catch (RuntimeException rte) {
                            dbDomImplementation.rollback();
                            JOptionPane.showMessageDialog(Gui.this, rte, "Excpetion", JOptionPane.ERROR_MESSAGE);
                        } finally {
                            dbDomImplementation.setAutoCommit (true);
                        }
                    } else {
                        // import canceled
                    }
                } catch (IOException ioe) {
                    JOptionPane.showMessageDialog(Gui.this, ioe, "I/O Excpetion", JOptionPane.ERROR_MESSAGE);
                }
            }
        }
    }

    private class GuiFileExporter implements ActionListener {
        public void actionPerformed (ActionEvent e) {
            DBDocument document = (DBDocument)domTree.getRootNode();
            if (document == null) {
                JOptionPane.showMessageDialog(Gui.this, "Load a document to export", "No document selected", JOptionPane.WARNING_MESSAGE);
                return;
            }

            // not a 100%, but usually a reasonable guess.
            File documentFile = new File (document.getDocumentName());
            fileChooser.setSelectedFile (documentFile);

            FileWriter documentWriter = null;
            int fileChooserReturned = JFileChooser.APPROVE_OPTION;

            while (fileChooserReturned == JFileChooser.APPROVE_OPTION  // user didn't cancel
                   && documentWriter == null) {                        // writing didn't start

                fileChooserReturned = fileChooser.showSaveDialog(Gui.this);

                if (fileChooserReturned == JFileChooser.APPROVE_OPTION) {
                    documentFile = fileChooser.getSelectedFile();
                    try {
                        if (documentFile.exists()) {
                            if (JOptionPane.showConfirmDialog(Gui.this, "Overwrite " + documentFile + "?", "File exists", JOptionPane.OK_CANCEL_OPTION) == JOptionPane.OK_OPTION) {
                                documentWriter = new FileWriter (documentFile);
                            } else {
                                // overwrite canceled
                            }
                        } else {
                            if (documentFile.createNewFile()) {
                                documentWriter = new FileWriter (documentFile);
                            } else {
                                JOptionPane.showMessageDialog(Gui.this, "couldn't create file " + documentFile, "Error", JOptionPane.ERROR_MESSAGE);
                            }
                        }
                    } catch (IOException ioe) {
                        JOptionPane.showMessageDialog(Gui.this, ioe.getMessage(), "Error", JOptionPane.ERROR_MESSAGE);
                    }
                }
            }
            if (documentWriter != null) {
                // this is where the actual export happens
                try {
                    XMLSerializer serializer = new XMLSerializer(documentWriter, null);  // use default output format
                    serializer.serialize (document);
                } catch (IOException ioe) {
                    JOptionPane.showMessageDialog(Gui.this, ioe, "I/O Excpetion", JOptionPane.ERROR_MESSAGE);
                }
            }
        }
    }
	
    private static void printUsage() {
        System.err.println ("Gui - sample gui application for DBDOM");
        System.err.println ("usage: java il.co.iter.dbdom.samples.Gui " +
            "<jdbc driver classname> " +
            "<connection string> <username> [password]");	
    }
}