-- create-tables.sql

CREATE TABLE t_NodeType (
	id			SMALLINT			CONSTRAINT pk_NodeType		PRIMARY KEY,
	name			VARCHAR (255)	NOT NULL	CONSTRAINT uq_NodeType_name	UNIQUE
);

CREATE TABLE t_Node (
	id			INT		NOT NULL	CONSTRAINT pk_Node		PRIMARY KEY,
	NodeType		SMALLINT	NOT NULL	CONSTRAINT fk_NodeType_Node	REFERENCES	t_NodeType(id),
	ownerDocument		INT		NULL		--REFERENCES	t_Node(id) ? REFERENCES t_Document(id)
	--					^==	'When this node is a Document this is null' - DOM level 1 Rec
								-- ownerDocument inplications are not clearly understood at this time
								-- it is'n always possible to compute this propertyby following the path:
								-- newly created nodes are not children to any node until inserted, but
								-- still must have a parentDocument, so they don't get inserted into
								-- another document, per level 1 Rec
);

CREATE TABLE t_archType (
	id			INT		NOT NULL,
	specified_in_dom	SMALLINT	DEFAULT 1	NOT NULL,	-- should have been BOOLEAN DEFAULT TRUE
										-- Attributes are not children of their parents in DOM, but in DBDOM they are.
										-- These arches are not visible in Node.getChildNodes, etc.
	parent_node_type_id	INT		NOT NULL	CONSTRAINT fk_NodeType_archType_parent	REFERENCES	t_NodeType(id),
	child_node_type_id	INT		NOT NULL	CONSTRAINT fk_NodeType_archType_child	REFERENCES	t_NodeType(id),
	max_nof_parents		SMALLINT	DEFAULT 1	NOT NULL,
	max_nof_children	SMALLINT	DEFAULT NULL	NULL,
	CONSTRAINT		pk_archType	PRIMARY KEY	(id, specified_in_dom)
);

CREATE TABLE t_arch (
	id			INT		NOT NULL	PRIMARY KEY,
	parent_node_id		INT		NOT NULL	CONSTRAINT fk_Node_arch_parent	REFERENCES	t_Node(id),
	child_node_id		INT		NOT NULL	CONSTRAINT fk_Node_arch_child	REFERENCES	t_Node(id),
	type_id			INT		NOT NULL,
	parent_ord_no		INT		NOT NULL,
	child_ord_no		INT		NOT NULL,
	specified_in_dom	SMALLINT	NOT NULL,	-- See comment in t_archType; sould have been BOOLEAN
								-- it would have been possible to find this property from t_arch JOIN t_archType;
								-- however, this is thought to be an unnessesary performance hit
	CONSTRAINT	       fk_archType_arch	FOREIGN KEY	(type_id, specified_in_dom)
				REFERENCES	t_archType	(id, specified_in_dom)
	-- CONSTRAINT		uq_arch_child_ord_no		(parent_node_id, child_ord_no)
	-- CONSTRAINT		uq_arch_parent_ord_no		(child_node_id, parent_ord_no)
);

CREATE TABLE t_attrName (
	id			INT				CONSTRAINT pk_attrName	PRIMARY KEY,
	name			VARCHAR (255)	NOT NULL	CONSTRAINT uq_attrName_name	UNIQUE
);

CREATE TABLE t_tag (
	id			INT				CONSTRAINT pk_tag	PRIMARY KEY,
	name			VARCHAR (255)	NOT NULL	CONSTRAINT uq_tag_name	UNIQUE
);

CREATE TABLE t_Attr (
	id			INT				CONSTRAINT pk_Attr	PRIMARY KEY
								CONSTRAINT fk_Node_Attr REFERENCES t_Node(id),
	name_id			INT		NOT NULL	CONSTRAINT fk_attrName_Attr REFERENCES	t_attrName(id),
	specified		SMALLINT	NOT NULL,	-- should have been BOOLEAN
	value			VARCHAR (255)
);

--
CREATE TABLE t_CharacterData (
	id			INT				CONSTRAINT pk_CharacterData	PRIMARY KEY
								CONSTRAINT fk_Node_CharacterData	REFERENCES t_Node(id),
	data			VARCHAR (255)	NOT NULL
);

CREATE TABLE t_Document (
	id			INT				CONSTRAINT pk_Document	PRIMARY KEY
								CONSTRAINT fk_Node_Document	REFERENCES t_Node(id)
);

CREATE TABLE t_DocumentFragment (
	id			INT				CONSTRAINT pk_DocumentFragment	PRIMARY KEY
								CONSTRAINT fk_Node_DocumentFragment	REFERENCES t_Node(id)
);

CREATE TABLE t_DocumentType (
	id			INT				CONSTRAINT pk_DocumentType	PRIMARY KEY
								CONSTRAINT fk_Node_DocumentType	REFERENCES t_Node(id),
	name			VARCHAR (255)	NOT NULL
);

CREATE TABLE t_Element (
	id			INT				CONSTRAINT pk_Element	PRIMARY KEY
								CONSTRAINT fk_Node_Element	REFERENCES t_Node(id),
	tag_id			INT		NOT NULL	CONSTRAINT fk_tag_Element	REFERENCES t_tag(id)
);

CREATE TABLE t_Entity (
	id			INT				CONSTRAINT pk_Entity	PRIMARY KEY
								CONSTRAINT fk_Node_Entity	REFERENCES t_Node(id),
	name			VARCHAR (255)	NOT NULL,
	publicId		VARCHAR (255)	NULL,
	systemId		VARCHAR (255)	NULL,
	notationName		VARCHAR (255)	NULL
);

CREATE TABLE t_Notation (
	id			INT				CONSTRAINT pk_Notation	PRIMARY KEY
								CONSTRAINT fk_Node_Notation	REFERENCES t_Node(id),
	name			VARCHAR (255)	NOT NULL,
	publicId		VARCHAR (255)	NULL,
	systemId		VARCHAR (255)	NULL
);

CREATE TABLE t_ProcessingInstruction (
	id			INT				CONSTRAINT pk_ProcessingInstruction	PRIMARY KEY
								CONSTRAINT fk_Node_ProcessingInstruction	REFERENCES t_Node(id),
	Target			VARCHAR (255)	NOT NULL,
	Data			VARCHAR (255)	NOT NULL
);

CREATE TABLE t_DOMException (
	id			SMALLINT			CONSTRAINT pk_DOMException	PRIMARY KEY,
	msg			VARCHAR (255)	NOT NULL,
	description		VARCHAR (255)	NOT NULL
);

CREATE TABLE t_DOMImplementation (
	feature			VARCHAR (255)			CONSTRAINT pk_DOMImplementation	PRIMARY KEY,
	version			VARCHAR (255)	NOT NULL
);

--------------------------------------------------------------------------
-- Private tables
--------------------------------------------------------------------------
CREATE TABLE t_DBDOMException (
	id			SMALLINT			CONSTRAINT pk_DBDOMException	PRIMARY KEY,
	msg			VARCHAR (255)	NOT NULL,
	description		VARCHAR (255)	NULL
);
