-- populate-tables.sql


--------------------------------------------------------------------------
-- Populate t_NodeType with constants
-- source http://www.w3.org/TR/REC-DOM-Level-1/level-one-core.html#ID-1950641247
--------------------------------------------------------------------------

INSERT INTO t_NodeType (id, name) VALUES ( 1, 'ELEENT_NODE');
INSERT INTO t_NodeType (id, name) VALUES ( 2, 'ATTRIBUTE_NODE');
INSERT INTO t_NodeType (id, name) VALUES ( 3, 'TEXT_NODE');
INSERT INTO t_NodeType (id, name) VALUES ( 4, 'CDATA_SECTION_NODE');
INSERT INTO t_NodeType (id, name) VALUES ( 5, 'ENTITY_REFERENCE_NODE');
INSERT INTO t_NodeType (id, name) VALUES ( 6, 'ENTITY_NODE');
INSERT INTO t_NodeType (id, name) VALUES ( 7, 'PROCESSING_INSTRUCTION_NODE');
INSERT INTO t_NodeType (id, name) VALUES ( 8, 'COMMENT_NODE');
INSERT INTO t_NodeType (id, name) VALUES ( 9, 'DOCUMENT_NODE');
INSERT INTO t_NodeType (id, name) VALUES (10, 'DOCUMENT_TYPE_NODE');
INSERT INTO t_NodeType (id, name) VALUES (11, 'DOCUMENT_FRAGMENT_NODE');
INSERT INTO t_NodeType (id, name) VALUES (12, 'NOTATION_NODE');


--------------------------------------------------------------------------
-- populate t_archType with valid child-parent pairs
-- source: http://www.w3.org/TR/REC-DOM-Level-1/level-one-core.html#ID-1590626202
--------------------------------------------------------------------------

-- Oracle note: id's are generated from sq_archType and inserted explicitly
--------------------------------------------------------------------------

-- Document -- Element (maximum of one), ProcessingInstruction, Comment, DocumentType
INSERT INTO t_archType (id, parent_node_type_id, child_node_type_id, max_nof_children) VALUES (sq_archType.NEXTVAL, 9, 1, 1);
INSERT INTO t_archType (id, parent_node_type_id, child_node_type_id) VALUES (sq_archType.NEXTVAL, 9,  7);
INSERT INTO t_archType (id, parent_node_type_id, child_node_type_id) VALUES (sq_archType.NEXTVAL, 9,  8);
INSERT INTO t_archType (id, parent_node_type_id, child_node_type_id) VALUES (sq_archType.NEXTVAL, 9, 10);

-- DocumentFragment -- Element, ProcessingInstruction, Comment, Text, CDATASection, EntityReference
INSERT INTO t_archType (id, parent_node_type_id, child_node_type_id) VALUES (sq_archType.NEXTVAL, 11, 1);
INSERT INTO t_archType (id, parent_node_type_id, child_node_type_id) VALUES (sq_archType.NEXTVAL, 11, 7);
INSERT INTO t_archType (id, parent_node_type_id, child_node_type_id) VALUES (sq_archType.NEXTVAL, 11, 8);
INSERT INTO t_archType (id, parent_node_type_id, child_node_type_id) VALUES (sq_archType.NEXTVAL, 11, 3);
INSERT INTO t_archType (id, parent_node_type_id, child_node_type_id) VALUES (sq_archType.NEXTVAL, 11, 4);
INSERT INTO t_archType (id, parent_node_type_id, child_node_type_id) VALUES (sq_archType.NEXTVAL, 11, 5);

-- DocumentType -- no children

-- EntityReference -- Element, ProcessingInstruction, Comment, Text, CDATASection, EntityReference
INSERT INTO t_archType (id, parent_node_type_id, child_node_type_id) VALUES (sq_archType.NEXTVAL, 5, 1);
INSERT INTO t_archType (id, parent_node_type_id, child_node_type_id) VALUES (sq_archType.NEXTVAL, 5, 7);
INSERT INTO t_archType (id, parent_node_type_id, child_node_type_id) VALUES (sq_archType.NEXTVAL, 5, 8);
INSERT INTO t_archType (id, parent_node_type_id, child_node_type_id) VALUES (sq_archType.NEXTVAL, 5, 3);
INSERT INTO t_archType (id, parent_node_type_id, child_node_type_id) VALUES (sq_archType.NEXTVAL, 5, 4);
INSERT INTO t_archType (id, parent_node_type_id, child_node_type_id) VALUES (sq_archType.NEXTVAL, 5, 5);

-- Element -- Element, Text, Comment, ProcessingInstruction, CDATASection, EntityReference
INSERT INTO t_archType (id, parent_node_type_id, child_node_type_id) VALUES (sq_archType.NEXTVAL, 1, 1);
INSERT INTO t_archType (id, parent_node_type_id, child_node_type_id) VALUES (sq_archType.NEXTVAL, 1, 3);
INSERT INTO t_archType (id, parent_node_type_id, child_node_type_id) VALUES (sq_archType.NEXTVAL, 1, 8);
INSERT INTO t_archType (id, parent_node_type_id, child_node_type_id) VALUES (sq_archType.NEXTVAL, 1, 7);
INSERT INTO t_archType (id, parent_node_type_id, child_node_type_id) VALUES (sq_archType.NEXTVAL, 1, 4);
INSERT INTO t_archType (id, parent_node_type_id, child_node_type_id) VALUES (sq_archType.NEXTVAL, 1, 5);
-- DOM eplicitly says Attributes are not children of their parents
INSERT INTO t_archType (id, specified_in_dom, parent_node_type_id, child_node_type_id) VALUES (sq_archType.NEXTVAL, 0, 1, 2);
--                                                                                                                  ^== FALSE

-- Attr -- Text, EntityReference
INSERT INTO t_archType (id, parent_node_type_id, child_node_type_id) VALUES (sq_archType.NEXTVAL, 2, 3);
INSERT INTO t_archType (id, parent_node_type_id, child_node_type_id) VALUES (sq_archType.NEXTVAL, 2, 5);

-- ProcessingInstruction -- no children

-- Comment -- no children

-- Text -- no children

-- CDATASection -- no children

-- Entity -- Element, ProcessingInstruction, Comment, Text, CDATASection, EntityReference
INSERT INTO t_archType (id, parent_node_type_id, child_node_type_id) VALUES (sq_archType.NEXTVAL, 6, 1);
INSERT INTO t_archType (id, parent_node_type_id, child_node_type_id) VALUES (sq_archType.NEXTVAL, 6, 7);
INSERT INTO t_archType (id, parent_node_type_id, child_node_type_id) VALUES (sq_archType.NEXTVAL, 6, 8);
INSERT INTO t_archType (id, parent_node_type_id, child_node_type_id) VALUES (sq_archType.NEXTVAL, 6, 3);
INSERT INTO t_archType (id, parent_node_type_id, child_node_type_id) VALUES (sq_archType.NEXTVAL, 6, 4);
INSERT INTO t_archType (id, parent_node_type_id, child_node_type_id) VALUES (sq_archType.NEXTVAL, 6, 5);

-- Notation -- no children


--------------------------------------------------------------------------
-- populate t_DOMException with exception codes and messages
-- source: http://www.w3.org/TR/REC-DOM-Level-1/level-one-core.html#ID-17189187
--------------------------------------------------------------------------

INSERT INTO t_DOMException (id, msg, description) VALUES ( 1, 'INDEX_SIZE_ERR',			'index or size is negative, or greater than the allowed value');
INSERT INTO t_DOMException (id, msg, description) VALUES ( 2, 'DOMSTRING_SIZE_ERR',		'the specified range of text does not fit into a DOMString');
INSERT INTO t_DOMException (id, msg, description) VALUES ( 3, 'HIERARCHY_REQUEST_ERR',		'a node is inserted somewhere it doesn''t belong');
INSERT INTO t_DOMException (id, msg, description) VALUES ( 4, 'WRONG_DOCUMENT_ERR',		'a node is used in a different document than the one that created it (that doesn''t support it)');
INSERT INTO t_DOMException (id, msg, description) VALUES ( 5, 'INVALID_CHARACTER_ERR',		'an invalid character is specified, such as in a name');
INSERT INTO t_DOMException (id, msg, description) VALUES ( 6, 'NO_DATA_ALLOWED_ERR',		'data is specified for a node which does not support data');
INSERT INTO t_DOMException (id, msg, description) VALUES ( 7, 'NO_MODIFICATION_ALLOWED_ERR',	'an attempt is made to modify an object where modifications are not allowed');
INSERT INTO t_DOMException (id, msg, description) VALUES ( 8, 'NOT_FOUND_ERR',			'an attempt was made to reference a node in a context where it does not exist');
INSERT INTO t_DOMException (id, msg, description) VALUES ( 9, 'NOT_SUPPORTED_ERR',		'the implementation does not support the type of object requested');
INSERT INTO t_DOMException (id, msg, description) VALUES (10, 'INUSE_ATTRIBUTE_ERR',		'an attempt is made to add an attribute that is already inuse elsewhere');


--------------------------------------------------------------------------
-- populate t_DOMImplementation with fratures and versions
-- source: http://www.w3.org/TR/REC-DOM-Level-1/level-one-core.html#ID-102161490
--------------------------------------------------------------------------

INSERT INTO t_DOMImplementation (feature, version) VALUES ('XML',	'1.0');
-- HTML is not supported
-- INSERT INTO t_DOMImplementation (feature, version) VALUES ('HTML',	'1.0');

-- DBDOM is supporded. This is a conveniant way to store current version information
INSERT INTO t_DOMImplementation (feature, version) VALUES ('DBDOM',	'0.1');


--------------------------------------------------------------------------
-- Populate private tables
--------------------------------------------------------------------------

--------------------------------------------------------------------------
-- populate t_DBDOMException with exception codes and messages
--------------------------------------------------------------------------

INSERT INTO t_DBDOMException (id, msg, description) VALUES ( 1, 'Type mismatch: object is %, expected %.',	'a Node of this type cannot participate in this expession');
INSERT INTO t_DBDOMException (id, msg, description) VALUES ( 2, 'Index % not found in table%.',			'the pointer references an non-existant Node; null pointer');


