-- create-tables.pgsql

CREATE TABLE t_NodeType (
	id			SMALLINT	NOT NULL	PRIMARY KEY,
	name			VARCHAR		NOT NULL	UNIQUE
);

CREATE TABLE t_Node (
	id			SERIAL		NOT NULL	PRIMARY KEY,
	--			^==	Postgres-specific syntax
	NodeType		SMALLINT	NOT NULL	REFERENCES	t_NodeType(id),
	ownerDocument		INT		NULL		--REFERENCES	t_Node(id) ? REFERENCES t_Document(id)
	--					^==	'When this node is a Document this is null' - DOM level 1 Rec
								-- ownerDocument inplications are not clearly understood at this time
								-- it is'n always possible to compute this propertyby following the path:
								-- newly created nodes are not children to any node until inserted, but
								-- still must have a parentDocument, so they don't get inserted into
								-- another document, per level 1 Rec
);

CREATE TABLE t_arch_type (
	id			SERIAL		NOT NULL,
	--			^==	Postgres-specific syntax
	specified_in_dom	BOOLEAN		NOT NULL	DEFAULT TRUE,	-- Attributes are not children of their parents in DOM, but in DBDOM they are.
										-- These arches are not visible in Node.getChildNodes, etc.
	parent_node_type_id	INT		NOT NULL	REFERENCES	t_NodeType(id),
	child_node_type_id	INT		NOT NULL	REFERENCES	t_NodeType(id),
	max_nof_parents		SMALLINT	NOT NULL	DEFAULT 1,
	max_nof_children	SMALLINT	NULL		DEFAULT NULL,
	PRIMARY KEY		(id, specified_in_dom)
);

CREATE TABLE t_arch (
	id			SERIAL		NOT NULL	PRIMARY KEY,
	--			^==	Postgres-specific syntax
	parent_node_id		INT		NOT NULL	REFERENCES	t_Node(id),
	child_node_id		INT		NOT NULL	REFERENCES	t_Node(id),
	type_id			INT		NOT NULL,
	parent_ord_no		INT		NOT NULL,
	child_ord_no		INT		NOT NULL,
	specified_in_dom	BOOLEAN		NOT NULL,	-- See comment in t_arch_type
	FOREIGN KEY		(type_id, specified_in_dom)
		REFERENCES	t_arch_type(id, specified_in_dom)
);

CREATE TABLE t_attr_name (
	id			SERIAL		NOT NULL	PRIMARY KEY,
	--			^==	Postgres-specific syntax
	name			VARCHAR		NOT NULL	UNIQUE
);

CREATE TABLE t_tag (
	id			SERIAL		NOT NULL	PRIMARY KEY,
	--			^==	Postgres-specific syntax
	name			VARCHAR		NOT NULL	UNIQUE
);

CREATE TABLE t_Attr (
	id			INT		NOT NULL	PRIMARY KEY	REFERENCES t_Node(id),
	name_id			INT		NOT NULL	REFERENCES	t_attr_name(id),
	specified		BOOLEAN		NOT NULL,
	value			VARCHAR
);

--
CREATE TABLE t_CharacterData (
	id			INT		NOT NULL	PRIMARY KEY	REFERENCES t_Node(id),
	data			VARCHAR		NOT NULL
);

CREATE TABLE t_Document (
	id			INT		NOT NULL	PRIMARY KEY	REFERENCES t_Node(id),
	-- Non-DOM; a unique name used to identify this document within the database
	name			VARCHAR		NOT NULL	UNIQUE
);

CREATE TABLE t_DocumentFragment (
	id			INT		NOT NULL	PRIMARY KEY	REFERENCES t_Node(id)
);

CREATE TABLE t_DocumentType (
	id			INT		NOT NULL	PRIMARY KEY	REFERENCES t_Node(id),
	name			VARCHAR		NOT NULL
);

CREATE TABLE t_Element (
	id			INT		NOT NULL	PRIMARY KEY	REFERENCES t_Node(id),
	tag_id			INT		NOT NULL	REFERENCES	t_tag(id)
);

CREATE TABLE t_Entity (
	id			INT		NOT NULL	PRIMARY KEY	REFERENCES t_Node(id),
	name			VARCHAR		NOT NULL,
	publicId		VARCHAR		NULL,
	systemId		VARCHAR		NULL,
	notationName		VARCHAR		NULL
);

CREATE TABLE t_Notation (
	id			INT		NOT NULL	PRIMARY KEY	REFERENCES t_Node(id),
	name			VARCHAR		NOT NULL,
	publicId		VARCHAR		NULL,
	systemId		VARCHAR		NULL
);

CREATE TABLE t_ProcessingInstruction (
	id			INT		NOT NULL	PRIMARY KEY	REFERENCES t_Node(id),
	Target			VARCHAR		NOT NULL,
	Data			VARCHAR		NOT NULL
);

CREATE TABLE t_DOMException (
	id			SMALLINT	NOT NULL	PRIMARY KEY,
	msg			VARCHAR		NOT NULL,
	description		VARCHAR		NOT NULL
);

CREATE TABLE t_DOMImplementation (
	feature			VARCHAR		NOT NULL	PRIMARY KEY,
	version			VARCHAR		NOT NULL
);

--------------------------------------------------------------------------
-- Private tables
--------------------------------------------------------------------------
-- a table to hold codes and explanations of propriatory DBDOMExceptions
CREATE TABLE t_DBDOMException (
	id			SMALLINT	NOT NULL	PRIMARY KEY,
	msg			VARCHAR		NOT NULL,
	description		VARCHAR		NULL
);

-- a table to hold constant values
CREATE TABLE t_settings (
	id			SMALLINT	NOT NULL	PRIMARY KEY,
	name			VARCHAR		NOT NULL,
	value			VARCHAR		NOT NULL
);

