-- populate-tables.sql


--------------------------------------------------------------------------
-- Populate t_NodeType with constants
-- source http://www.w3.org/TR/REC-DOM-Level-1/level-one-core.html#ID-1950641247
--------------------------------------------------------------------------

INSERT INTO t_NodeType (id, name) VALUES ( 1, 'ELEMENT_NODE');
INSERT INTO t_NodeType (id, name) VALUES ( 2, 'ATTRIBUTE_NODE');
INSERT INTO t_NodeType (id, name) VALUES ( 3, 'TEXT_NODE');
INSERT INTO t_NodeType (id, name) VALUES ( 4, 'CDATA_SECTION_NODE');
INSERT INTO t_NodeType (id, name) VALUES ( 5, 'ENTITY_REFERENCE_NODE');
INSERT INTO t_NodeType (id, name) VALUES ( 6, 'ENTITY_NODE');
INSERT INTO t_NodeType (id, name) VALUES ( 7, 'PROCESSING_INSTRUCTION_NODE');
INSERT INTO t_NodeType (id, name) VALUES ( 8, 'COMMENT_NODE');
INSERT INTO t_NodeType (id, name) VALUES ( 9, 'DOCUMENT_NODE');
INSERT INTO t_NodeType (id, name) VALUES (10, 'DOCUMENT_TYPE_NODE');
INSERT INTO t_NodeType (id, name) VALUES (11, 'DOCUMENT_FRAGMENT_NODE');
INSERT INTO t_NodeType (id, name) VALUES (12, 'NOTATION_NODE');


--------------------------------------------------------------------------
-- populate t_arch_type with valid child-parent pairs
-- source: http://www.w3.org/TR/REC-DOM-Level-1/level-one-core.html#ID-1590626202
--------------------------------------------------------------------------

-- Document -- Element (maximum of one), ProcessingInstruction, Comment, DocumentType
INSERT INTO t_arch_type (parent_node_type_id, child_node_type_id, max_nof_children) VALUES (9, 1, 1);
INSERT INTO t_arch_type (parent_node_type_id, child_node_type_id) VALUES (9,  7);
INSERT INTO t_arch_type (parent_node_type_id, child_node_type_id) VALUES (9,  8);
INSERT INTO t_arch_type (parent_node_type_id, child_node_type_id) VALUES (9, 10);

-- DocumentFragment -- Element, ProcessingInstruction, Comment, Text, CDATASection, EntityReference
INSERT INTO t_arch_type (parent_node_type_id, child_node_type_id) VALUES (11, 1);
INSERT INTO t_arch_type (parent_node_type_id, child_node_type_id) VALUES (11, 7);
INSERT INTO t_arch_type (parent_node_type_id, child_node_type_id) VALUES (11, 8);
INSERT INTO t_arch_type (parent_node_type_id, child_node_type_id) VALUES (11, 3);
INSERT INTO t_arch_type (parent_node_type_id, child_node_type_id) VALUES (11, 4);
INSERT INTO t_arch_type (parent_node_type_id, child_node_type_id) VALUES (11, 5);

-- DocumentType -- no children

-- EntityReference -- Element, ProcessingInstruction, Comment, Text, CDATASection, EntityReference
INSERT INTO t_arch_type (parent_node_type_id, child_node_type_id) VALUES (5, 1);
INSERT INTO t_arch_type (parent_node_type_id, child_node_type_id) VALUES (5, 7);
INSERT INTO t_arch_type (parent_node_type_id, child_node_type_id) VALUES (5, 8);
INSERT INTO t_arch_type (parent_node_type_id, child_node_type_id) VALUES (5, 3);
INSERT INTO t_arch_type (parent_node_type_id, child_node_type_id) VALUES (5, 4);
INSERT INTO t_arch_type (parent_node_type_id, child_node_type_id) VALUES (5, 5);

-- Element -- Element, Text, Comment, ProcessingInstruction, CDATASection, EntityReference
INSERT INTO t_arch_type (parent_node_type_id, child_node_type_id) VALUES (1, 1);
INSERT INTO t_arch_type (parent_node_type_id, child_node_type_id) VALUES (1, 3);
INSERT INTO t_arch_type (parent_node_type_id, child_node_type_id) VALUES (1, 8);
INSERT INTO t_arch_type (parent_node_type_id, child_node_type_id) VALUES (1, 7);
INSERT INTO t_arch_type (parent_node_type_id, child_node_type_id) VALUES (1, 4);
INSERT INTO t_arch_type (parent_node_type_id, child_node_type_id) VALUES (1, 5);
-- DOM eplicitly says Attributes are not children of their parents
INSERT INTO t_arch_type (specified_in_dom, parent_node_type_id, child_node_type_id) VALUES (FALSE, 1, 2);

-- Attr -- Text, EntityReference
INSERT INTO t_arch_type (parent_node_type_id, child_node_type_id) VALUES (2, 3);
INSERT INTO t_arch_type (parent_node_type_id, child_node_type_id) VALUES (2, 5);

-- ProcessingInstruction -- no children

-- Comment -- no children

-- Text -- no children

-- CDATASection -- no children

-- Entity -- Element, ProcessingInstruction, Comment, Text, CDATASection, EntityReference
INSERT INTO t_arch_type (parent_node_type_id, child_node_type_id) VALUES (6, 1);
INSERT INTO t_arch_type (parent_node_type_id, child_node_type_id) VALUES (6, 7);
INSERT INTO t_arch_type (parent_node_type_id, child_node_type_id) VALUES (6, 8);
INSERT INTO t_arch_type (parent_node_type_id, child_node_type_id) VALUES (6, 3);
INSERT INTO t_arch_type (parent_node_type_id, child_node_type_id) VALUES (6, 4);
INSERT INTO t_arch_type (parent_node_type_id, child_node_type_id) VALUES (6, 5);

-- Notation -- no children


--------------------------------------------------------------------------
-- populate t_DOMException with exception codes and messages
-- source: http://www.w3.org/TR/REC-DOM-Level-1/level-one-core.html#ID-17189187
--------------------------------------------------------------------------

INSERT INTO t_DOMException (id, msg, description) VALUES ( 1, 'INDEX_SIZE_ERR',			'index or size is negative, or greater than the allowed value');
INSERT INTO t_DOMException (id, msg, description) VALUES ( 2, 'DOMSTRING_SIZE_ERR',		'the specified range of text does not fit into a DOMString');
INSERT INTO t_DOMException (id, msg, description) VALUES ( 3, 'HIERARCHY_REQUEST_ERR',		'a node is inserted somewhere it doesn''t belong');
INSERT INTO t_DOMException (id, msg, description) VALUES ( 4, 'WRONG_DOCUMENT_ERR',		'a node is used in a different document than the one that created it (that doesn''t support it)');
INSERT INTO t_DOMException (id, msg, description) VALUES ( 5, 'INVALID_CHARACTER_ERR',		'an invalid character is specified, such as in a name');
INSERT INTO t_DOMException (id, msg, description) VALUES ( 6, 'NO_DATA_ALLOWED_ERR',		'data is specified for a node which does not support data');
INSERT INTO t_DOMException (id, msg, description) VALUES ( 7, 'NO_MODIFICATION_ALLOWED_ERR',	'an attempt is made to modify an object where modifications are not allowed');
INSERT INTO t_DOMException (id, msg, description) VALUES ( 8, 'NOT_FOUND_ERR',			'an attempt was made to reference a node in a context where it does not exist');
INSERT INTO t_DOMException (id, msg, description) VALUES ( 9, 'NOT_SUPPORTED_ERR',		'the implementation does not support the type of object requested');
INSERT INTO t_DOMException (id, msg, description) VALUES (10, 'INUSE_ATTRIBUTE_ERR',		'an attempt is made to add an attribute that is already inuse elsewhere');
INSERT INTO t_DOMException (id, msg, description) VALUES (11, 'INVALID_STATE_ERR',		'an attempt is made to use an object that is not, or is no longer usable');
INSERT INTO t_DOMException (id, msg, description) VALUES (12, 'SYNTAX_ERR',			'an invalid or illegal string is specified');
INSERT INTO t_DOMException (id, msg, description) VALUES (13, 'INVALID_MODIFICATION_ERR',	'an attempt is made to modify the type of the underlying object');
INSERT INTO t_DOMException (id, msg, description) VALUES (14, 'NAMESPACE_ERR',			'an attempt is made to create or change an object in a way which is incorrect with regard to namespaces');
INSERT INTO t_DOMException (id, msg, description) VALUES (15, 'INVALID_ACCESS_ERR',		'a parameter or an operation is not supported by the underlying object');


--------------------------------------------------------------------------
-- populate t_DOMImplementation with fratures and versions
-- source: http://www.w3.org/TR/REC-DOM-Level-1/level-one-core.html#ID-102161490
--------------------------------------------------------------------------

INSERT INTO t_DOMImplementation (feature, version) VALUES ('XML',	'1.0');
-- HTML is not supported
-- INSERT INTO t_DOMImplementation (feature, version) VALUES ('HTML',	'1.0');

-- DBDOM is supporded. This is a conveniant way to store current version information
INSERT INTO t_DOMImplementation (feature, version) VALUES ('DBDOM',	'0.1');


--------------------------------------------------------------------------
-- Populate private tables
--------------------------------------------------------------------------

--------------------------------------------------------------------------
-- populate t_DBDOMException with exception codes and messages
--------------------------------------------------------------------------

INSERT INTO t_DBDOMException (id, msg, description) VALUES ( 1, 'Type mismatch: object is %, expected %.');
INSERT INTO t_DBDOMException (id, msg, description) VALUES ( 2, 'Index % not found in table%.');

--------------------------------------------------------------------------
-- populate t_settings with names and values
--------------------------------------------------------------------------

-- the value to be added to the code of a DBDOMException, so as to avoid
-- clashes with DOMException codes
INSERT INTO t_settings (id, name, value) VALUES ( 1, 'dbdomExceptionCodeOffset', '512');
-- the prefix to be added to the message of a DOMEXception to let the
-- application know that a DOMException was thrown, as opposed to a
-- regular exception. this value should be reasonably unique ( in particular
-- DOMException by itself is a poor choice, because it may be used to report
-- a difficulty with raisinf a DOMException, and include no spaces, as space
-- is will be used as a delimiter
INSERT INTO t_settings (id, name, value) VALUES ( 2, 'domExceptionPrefix', '##DOMException##');

